@@ -1,47 +1,20 @@
 #' Estimate R-squared
 #'
-#' @param fitted_values fitted values from a regression function using the
-#'   observed data.
-#' @param y the observed outcome.
-#' @param full_y the observed outcome (defaults to \code{NULL}; allows the 
-#'   full-data outcome to be used for empirical estimates that do not rely 
-#'   on covariates).
-#' @param C the indicator of coarsening (1 denotes observed, 0 denotes
-#'   unobserved).
-#' @param Z either \code{NULL} (if no coarsening) or a matrix-like object
-#'   containing the fully observed data.
-#' @param ipc_weights weights for inverse probability of coarsening (e.g.,
-#'   inverse weights from a two-phase sample) weighted estimation.
-#'   Assumed to be already inverted
-#'   (i.e., ipc_weights = 1 / [estimated probability weights]).
-#' @param ipc_fit_type if "external", then use \code{ipc_eif_preds}; if "SL",
-#'   fit a SuperLearner to determine the correction to the efficient
-#'   influence function.
-#' @param ipc_eif_preds if \code{ipc_fit_type = "external"}, the fitted values
-#'   from a regression of the full-data EIF on the fully observed
-#'   covariates/outcome; otherwise, not used.
-#' @param ipc_est_type IPC correction, either \code{"ipw"} (for classical
-#'   inverse probability weighting) or \code{"aipw"} (for augmented inverse
-#'   probability weighting; the default).
-#' @param scale if doing an IPC correction, then the scale that the correction
-#'   should be computed on (e.g., "identity"; or "logit" to logit-transform,
-#'   apply the correction, and back-transform).
-#' @param na.rm logical; should \code{NA}s be removed in computation?
-#'   (defaults to \code{FALSE})
-#' @param ... other arguments to SuperLearner, if \code{ipc_fit_type = "SL"}.
+#' @inheritParams measure_accuracy
 #'
 #' @return A named list of: (1) the estimated R-squared of the fitted regression
 #'    function; (2) the estimated influence function; and
 #'    (3) the IPC EIF predictions.
 #' @importFrom SuperLearner predict.SuperLearner SuperLearner
 #' @export
-measure_r_squared <- function(fitted_values, y, full_y = NULL, 
+measure_r_squared <- function(fitted_values, y, full_y = NULL,
                               C = rep(1, length(y)), Z = NULL,
                               ipc_weights = rep(1, length(y)),
                               ipc_fit_type = "external",
                               ipc_eif_preds = rep(1, length(y)),
                               ipc_est_type = "aipw", scale = "identity",
-                              na.rm = FALSE, ...) {
+                              na.rm = FALSE, nuisance_estimators = NULL,
+                              a = NULL, ...) {
     if (is.null(full_y)) {
         obs_mn_y <- mean(y, na.rm = na.rm)
     } else {
@@ -60,15 +33,9 @@ measure_r_squared <- function(fitted_values, y, full_y = NULL,
                    nrow = 1) %*% t(cbind(obs_mse$eif, obs_var$eif))
         )
         # if IPC EIF preds aren't entered, estimate the regression
-        if (ipc_fit_type != "external") {
-            ipc_eif_mod <- SuperLearner::SuperLearner(
-                Y = obs_grad, X = subset(Z, C == 1, drop = FALSE),
-                method = "method.CC_LS", ...
-            )
-            ipc_eif_preds <- SuperLearner::predict.SuperLearner(
-                ipc_eif_mod, newdata = Z, onlySL = TRUE
-            )$pred
-        }
+        ipc_eif_preds <- estimate_eif_projection(obs_grad = obs_grad, C = C,
+                                                 Z = Z, ipc_fit_type = ipc_fit_type,
+                                                 ipc_eif_preds = ipc_eif_preds, ...)
         weighted_obs_grad <- rep(0, length(C))
         weighted_obs_grad[C == 1] <- obs_grad * ipc_weights[C == 1]
         grad <- weighted_obs_grad - (C * ipc_weights - 1) * ipc_eif_preds
@@ -85,7 +52,7 @@ measure_r_squared <- function(fitted_values, y, full_y = NULL,
     } else {
         # point estimates of all components
         mse <- measure_mse(fitted_values, y, na.rm = na.rm)
-        var <- measure_mse(fitted_values = rep(obs_mn_y, length(y)), y, 
+        var <- measure_mse(fitted_values = rep(obs_mn_y, length(y)), y,
                            na.rm = na.rm)
         est <- 1 - mse$point_est / var$point_est
         # influence curve
