@@ -144,11 +144,11 @@ set.seed(1234)
 sample_splitting_folds <- make_folds(unique(cross_fitting_folds), V = 2)
 full_cv_preds <- extract_sampled_split_predictions(
   cvsl_obj = full_cv_fit, sample_splitting = TRUE, 
-  sample_splitting_folds = sample_splitting_folds, full = TRUE
+  sample_splitting_folds = sample_splitting_folds, full = TRUE, vector = TRUE
 )
 reduced_cv_preds <- extract_sampled_split_predictions(
   cvsl_obj = reduced_cv_fit, sample_splitting = TRUE, 
-  sample_splitting_folds = sample_splitting_folds, full = FALSE
+  sample_splitting_folds = sample_splitting_folds, full = FALSE, vector = TRUE
 )
 set.seed(5678)
 # refit without cross-fitting (for non-cross-fitted SE estimation)
@@ -188,6 +188,56 @@ test_that("Cross-validated variable importance using externally-computed regress
   # check the actual value of the point estimate
   # expect_equal(sprintf("%.15f", est_prefit$est), "0.311079577886281")
 })
+test_that("Cross-validated variable importance using non-list externally-computed regressions works", {
+  est_prefit <- cv_vim(Y = y, cross_fitted_f1 = full_cv_fit$SL.predict, 
+                       cross_fitted_f2 = reduced_cv_fit$SL.predict, indx = 2, 
+                       delta = 0, V = V, 
+                       type = "r_squared", cross_fitting_folds = cross_fitting_folds, 
+                       sample_splitting_folds = sample_splitting_folds,
+                       run_regression = FALSE, alpha = 0.05, na.rm = TRUE)
+  # check variable importance estimate
+  expect_equal(est_prefit$est, r2_two, tolerance = 0.1, scale = 1)
+  # check full predictiveness estimate
+  expect_equal(est_prefit$predictiveness_full, 0.44, tolerance = 0.1, scale = 1)
+  # check that the SE, CI work
+  expect_length(est_prefit$ci, 2)
+  expect_length(est_prefit$se, 1)
+  # check that the p-value worked
+  expect_length(est_prefit$p_value, 1)
+  expect_true(est_prefit$test)
+  # check that printing, plotting, etc. work
+  expect_silent(format(est_prefit)[1])
+  expect_output(print(est_prefit), "Estimate", fixed = TRUE)
+  # check that influence curve worked
+  expect_length(est_prefit$eif, length(y) / 2)
+  # check the actual value of the point estimate
+  # expect_equal(sprintf("%.15f", est_prefit$est), "0.311079577886281")
+})
+test_that("Cross-validated variable importance using non-list externally-computed regressions and no sample-splitting works", {
+  est_prefit <- cv_vim(Y = y, cross_fitted_f1 = full_cv_fit$SL.predict, 
+                       cross_fitted_f2 = reduced_cv_fit$SL.predict, indx = 2, 
+                       delta = 0, V = 2 * V, 
+                       type = "r_squared", cross_fitting_folds = cross_fitting_folds, 
+                       sample_splitting = FALSE,
+                       run_regression = FALSE, alpha = 0.05, na.rm = TRUE)
+  # check variable importance estimate
+  expect_equal(est_prefit$est, r2_two, tolerance = 0.1, scale = 1)
+  # check full predictiveness estimate
+  expect_equal(est_prefit$predictiveness_full, 0.44, tolerance = 0.1, scale = 1)
+  # check that the SE, CI work
+  expect_length(est_prefit$ci, 2)
+  expect_length(est_prefit$se, 1)
+  # check that the p-value worked
+  expect_length(est_prefit$p_value, 1)
+  expect_true(est_prefit$test)
+  # check that printing, plotting, etc. work
+  expect_silent(format(est_prefit)[1])
+  expect_output(print(est_prefit), "Estimate", fixed = TRUE)
+  # check that influence curve worked
+  expect_length(est_prefit$eif, length(y))
+  # check the actual value of the point estimate
+  # expect_equal(sprintf("%.15f", est_prefit$est), "0.311079577886281")
+})
 
 # non-cross-fitted SEs
 test_that("Cross-validated variable importance using externally-computed regressions and non-cross-fitted SEs works", {
@@ -218,10 +268,14 @@ test_that("Cross-validated variable importance using externally-computed regress
 })
 
 # measures of predictiveness ---------------------------------------------------
+full_cv_preds_list <- extract_sampled_split_predictions(
+  cvsl_obj = full_cv_fit, sample_splitting = TRUE, 
+  sample_splitting_folds = sample_splitting_folds, full = TRUE, vector = FALSE
+)
 test_that("Measures of predictiveness work", {
   k_fold_lst <- make_kfold(cross_fitting_folds, sample_splitting_folds)    
   full_test <- (k_fold_lst$sample_splitting_folds == 1)
-  full_rsquared <- est_predictiveness_cv(fitted_values = full_cv_preds, 
+  full_rsquared <- est_predictiveness_cv(fitted_values = full_cv_preds_list, 
                                          y = y[full_test],
                                          full_y = y,
                                          folds = k_fold_lst$full, 
@@ -265,11 +319,11 @@ set.seed(1234)
 sample_splitting_folds <- make_folds(unique(cross_fitting_folds), V = 2)
 full_cv_preds <- extract_sampled_split_predictions(
   cvsl_obj = full_cv_fit, sample_splitting = TRUE, 
-  sample_splitting_folds = sample_splitting_folds, full = TRUE
+  sample_splitting_folds = sample_splitting_folds, full = TRUE, vector = TRUE
 )
 reduced_cv_preds <- extract_sampled_split_predictions(
   cvsl_obj = reduced_cv_fit, sample_splitting = TRUE, 
-  sample_splitting_folds = sample_splitting_folds, full = FALSE
+  sample_splitting_folds = sample_splitting_folds, full = FALSE, vector = TRUE
 )
 test_that("Cross-validated VIM works with externally-computed regressions and an odd number of folds", {
   est_prefit <- cv_vim(Y = y, cross_fitted_f1 = full_cv_preds, 
