@@ -40,7 +40,7 @@ set.seed(1234)
 # test that VIM with inverse probability of coarsening weights works
 test_that("VIM with inverse probability of coarsening weights works", {
   est <- vim(Y = y, X = x_df, indx = 1, type = "r_squared", run_regression = TRUE, 
-             SL.library = learners,
+             SL.library = learners, method = "method.CC_LS",
              alpha = 0.05, delta = 0, C = C, Z = "Y", ipc_weights = ipc_weights,
              cvControl = list(V = V), env = environment())
   expect_equal(est$est, r2_one, tolerance = 0.2, scale = 1)
@@ -58,7 +58,7 @@ test_that("IPW AUC estimation with the mean works", {
                          full_y = y_bin, C = cc, Z = data.frame(Y = y_bin), 
                          ipc_est_type = "ipw",
                          ipc_weights = ipc_weights, ipc_fit_type = "SL",
-                         SL.library = "SL.glm")
+                         SL.library = "SL.glm", method = "method.CC_LS",)
   expect_equal(est_auc$point_est, 0.5, tolerance = 0.001, scale = 1)
 })
 set.seed(121314)
@@ -70,16 +70,16 @@ test_that("IPW AUC estimation with a better learner works", {
                          full_y = y_bin, C = cc, Z = data.frame(Y = y_bin), 
                          ipc_est_type = "ipw",
                          ipc_weights = ipc_weights, ipc_fit_type = "SL",
-                         SL.library = "SL.glm")
+                         SL.library = "SL.glm", method = "method.CC_LS",)
   expect_equal(est_auc$point_est, true_auc, tolerance = 0.1, scale = 1)
 })
-set.seed(5678)
 
 # test IPW CV-VIM --------------------------------------------------------------
 # test that VIM with inverse probability of coarsening weights and cross-fitting works
+set.seed(5678)
 test_that("CV-VIM with inverse probability of coarsening weights works", {
   est_cv <- cv_vim(Y = y, X = x_df, indx = 1, type = "r_squared", V = 2, 
-                   run_regression = TRUE, SL.library = learners,
+                   run_regression = TRUE, SL.library = learners[1], method = "method.CC_LS",
              alpha = 0.05, delta = 0, C = C, Z = "Y", ipc_weights = ipc_weights,
              cvControl = list(V = V), env = environment())
   expect_equal(est_cv$est, r2_one, tolerance = 0.3, scale = 1)
@@ -92,10 +92,33 @@ set.seed(91011)
 # test that SPVIM with inverse probability of coarsening weights works
 test_that("SPVIM with inverse probability of coarsening weights works", {
   expect_warning(est_spvim <- sp_vim(Y = y, X = x_df, type = "r_squared", V = 2, 
-                      SL.library = learners,
+                      SL.library = learners, method = "method.CC_LS",
                       univariate_SL.library = univariate_learners, gamma = 0.1,
                       alpha = 0.05, delta = 0, C = C, Z = "Y", 
                       ipc_weights = ipc_weights,
                       cvControl = list(V = 2), env = environment()))
   expect_equal(est_spvim$est[3], shapley_val_2, tolerance = 0.3, scale = 1)
 })
+# binary SPVIM
+set.seed(1234)
+n <- 250
+W <- runif(n, min = -1,  max = 1)
+A <- rbinom(n, size = 1, prob = plogis(W))
+Y <- rbinom(n,1,plogis(A * (1 + W + 2*W^2) + sin(5*W)))
+propW <- 1/rnorm(n,0.5,0.1)
+censoringW <-  runif(n, min = 1,  max = 5)
+data <- data.frame(W,A,Y, propW, censoringW)
+
+X_for_vim <- data.frame(X1 = W, X2=A)
+
+set.seed(5678)
+test_that("SPVIM with IPW and binary outcome works", {
+  expect_warning(est <- sp_vim(Y = Y, X = X_for_vim, V = 2, type = "auc", 
+                               SL.library = learners,
+                               univariate_SL.library = univariate_learners, gamma = 0.1,
+                               stratified = TRUE, C = rep(1,nrow(X_for_vim)),
+                               ipc_weights = propW*censoringW, ipc_est_type = "ipw",
+                               Z = c("Y","X1","X2")))
+  expect_equal(est$est[2], 0.1, tolerance = 0.05, scale = 1)
+})
+
